bug-gnulib
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH 2/2] maint: time stamp -> timestamp


From: Paul Eggert
Subject: [PATCH 2/2] maint: time stamp -> timestamp
Date: Mon, 9 Jan 2017 11:58:24 -0800

Use the spelling "timestamp", as that is what POSIX uses.
---
 build-aux/bootstrap                |  4 ++--
 build-aux/git-version-gen          |  4 ++--
 doc/install.texi                   |  2 +-
 doc/parse-datetime.texi            |  8 ++++----
 doc/posix-functions/ctime.texi     |  2 +-
 doc/posix-functions/inet_ntoa.texi |  2 +-
 lib/fdutimensat.c                  |  4 ++--
 lib/futimens.c                     |  4 ++--
 lib/mktime.c                       |  2 +-
 lib/parse-datetime.h               |  2 +-
 lib/parse-datetime.y               | 16 ++++++++--------
 lib/stat-time.h                    |  2 +-
 lib/time.in.h                      |  2 +-
 lib/timespec.h                     |  6 +++---
 lib/utimecmp.c                     | 32 ++++++++++++++++----------------
 lib/utimecmp.h                     |  4 ++--
 lib/utimens.c                      | 10 +++++-----
 lib/utimensat.c                    |  4 ++--
 lib/xtime.h                        |  4 ++--
 modules/utimecmp                   |  2 +-
 tests/test-posixtm.c               |  2 +-
 21 files changed, 59 insertions(+), 59 deletions(-)

diff --git a/build-aux/bootstrap b/build-aux/bootstrap
index 26066b2..932ff85 100755
--- a/build-aux/bootstrap
+++ b/build-aux/bootstrap
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Print a version string.
-scriptversion=2016-11-03.18; # UTC
+scriptversion=2017-01-09.19; # UTC
 
 # Bootstrap this package from checked-out sources.
 
@@ -790,7 +790,7 @@ symlink_to_dir()
       # Leave any existing symlink alone, if it already points to the source,
       # so that broken build tools that care about symlink times
       # aren't confused into doing unnecessary builds.  Conversely, if the
-      # existing symlink's time stamp is older than the source, make it afresh,
+      # existing symlink's timestamp is older than the source, make it afresh,
       # so that broken tools aren't confused into skipping needed builds.  See
       # <http://lists.gnu.org/archive/html/bug-gnulib/2011-05/msg00326.html>.
       test -h "$dst" &&
diff --git a/build-aux/git-version-gen b/build-aux/git-version-gen
index c29f9e5..079849d 100755
--- a/build-aux/git-version-gen
+++ b/build-aux/git-version-gen
@@ -1,6 +1,6 @@
 #!/bin/sh
 # Print a version string.
-scriptversion=2016-05-08.18; # UTC
+scriptversion=2017-01-09.19; # UTC
 
 # Copyright (C) 2007-2017 Free Software Foundation, Inc.
 #
@@ -200,7 +200,7 @@ v=`echo "$v" |sed "s/^$prefix//"`
 # string we're using came from git.  I.e., skip the test if it's "UNKNOWN"
 # or if it came from .tarball-version.
 if test "x$v_from_git" != x; then
-  # Don't declare a version "dirty" merely because a time stamp has changed.
+  # Don't declare a version "dirty" merely because a timestamp has changed.
   git update-index --refresh > /dev/null 2>&1
 
   dirty=`exec 2>/dev/null;git diff-index --name-only HEAD` || dirty=
diff --git a/doc/install.texi b/doc/install.texi
index 776eab1..1b9627d 100644
--- a/doc/install.texi
+++ b/doc/install.texi
@@ -262,7 +262,7 @@ use an ANSI C compiler:
 @noindent
 and if that doesn't work, install pre-built binaries of GCC for HP-UX.
 
-HP-UX @command{make} updates targets which have the same time stamps as
+HP-UX @command{make} updates targets which have the same timestamps as
 their prerequisites, which makes it generally unusable when shipped
 generated files such as @command{configure} are involved.  Use GNU
 @command{make} instead.
diff --git a/doc/parse-datetime.texi b/doc/parse-datetime.texi
index 2b168a4..9568a4a 100644
--- a/doc/parse-datetime.texi
+++ b/doc/parse-datetime.texi
@@ -311,7 +311,7 @@ unambiguous numeric time zone corrections like 
@samp{-0500}, as
 described in the previous section.
 
 If neither a time zone item nor a time zone correction is supplied,
-time stamps are interpreted using the rules of the default time zone
+timestamps are interpreted using the rules of the default time zone
 (@pxref{Specifying time zone rules}).
 
 
@@ -478,12 +478,12 @@ year.
 @node Seconds since the Epoch
 @section Seconds since the Epoch
 
-If you precede a number with @samp{@@}, it represents an internal time
-stamp as a count of seconds.  The number can contain an internal
+If you precede a number with @samp{@@}, it represents an internal
+timestamp as a count of seconds.  The number can contain an internal
 decimal point (either @samp{.} or @samp{,}); any excess precision not
 supported by the internal representation is truncated toward minus
 infinity.  Such a number cannot be combined with any other date
-item, as it specifies a complete time stamp.
+item, as it specifies a complete timestamp.
 
 @cindex beginning of time, for POSIX
 @cindex epoch, for POSIX
diff --git a/doc/posix-functions/ctime.texi b/doc/posix-functions/ctime.texi
index 6bff20c..f5a7c27 100644
--- a/doc/posix-functions/ctime.texi
+++ b/doc/posix-functions/ctime.texi
@@ -17,7 +17,7 @@ This function may overflow its internal buffer if an invalid 
year is passed.
 @item
 The @code{ctime} function need not be reentrant, and consequently is
 not required to be thread safe.  Implementations of @code{ctime}
-typically write the time stamp into static buffer.  If two threads
+typically write the timestamp into static buffer.  If two threads
 call @code{ctime} at roughly the same time, you might end up with the
 wrong date in one of the threads, or some undefined string.  There is
 a re-entrant interface @code{ctime_r}.
diff --git a/doc/posix-functions/inet_ntoa.texi 
b/doc/posix-functions/inet_ntoa.texi
index a21f319..56b497d 100644
--- a/doc/posix-functions/inet_ntoa.texi
+++ b/doc/posix-functions/inet_ntoa.texi
@@ -18,7 +18,7 @@ mingw, MSVC 9.
 @item
 The @code{inet_ntoa} function need not be reentrant, and consequently
 is not required to be thread safe.  Implementations of
address@hidden typically write the time stamp into static buffer.
address@hidden typically write the timestamp into static buffer.
 If two threads call @code{inet_ntoa} at roughly the same time, you
 might end up with the wrong date in one of the threads, or some
 undefined string.
diff --git a/lib/mktime.c b/lib/mktime.c
index cd52835..2efd44a 100644
--- a/lib/mktime.c
+++ b/lib/mktime.c
@@ -153,7 +153,7 @@ isdst_differ (int a, int b)
 
 /* Return an integer value measuring (YEAR1-YDAY1 HOUR1:MIN1:SEC1) -
    (YEAR0-YDAY0 HOUR0:MIN0:SEC0) in seconds, assuming that the clocks
-   were not adjusted between the time stamps.
+   were not adjusted between the timestamps.
 
    The YEAR values uses the same numbering as TP->tm_year.  Values
    need not be in the usual range.  However, YEAR1 must not overflow
diff --git a/lib/parse-datetime.h b/lib/parse-datetime.h
index a777aac..fa6a9a3 100644
--- a/lib/parse-datetime.h
+++ b/lib/parse-datetime.h
@@ -1,4 +1,4 @@
-/* Parse a string into an internal time stamp.
+/* Parse a string into an internal timestamp.
 
    Copyright (C) 1995, 1997-1998, 2003-2004, 2007, 2009-2017 Free Software
    Foundation, Inc.
diff --git a/lib/parse-datetime.y b/lib/parse-datetime.y
index 30488d6..c604be6 100644
--- a/lib/parse-datetime.y
+++ b/lib/parse-datetime.y
@@ -1,5 +1,5 @@
 %{
-/* Parse a string into an internal time stamp.
+/* Parse a string into an internal timestamp.
 
    Copyright (C) 1999-2000, 2002-2017 Free Software Foundation, Inc.
 
@@ -24,7 +24,7 @@
    Modified by Paul Eggert <address@hidden> in August 1999 to do
    the right thing about local DST.  Also modified by Paul Eggert
    <address@hidden> in February 2004 to support
-   nanosecond-resolution time stamps, and in October 2004 to support
+   nanosecond-resolution timestamps, and in October 2004 to support
    TZ strings in dates.  */
 
 /* FIXME: Check for arithmetic overflow in all cases, not just
@@ -1066,8 +1066,8 @@ static table const relative_time_table[] =
 };
 
 /* The universal time zone table.  These labels can be used even for
-   time stamps that would not otherwise be valid, e.g., GMT time
-   stamps in London during summer.  */
+   timestamps that would not otherwise be valid, e.g., GMT timestamps
+   oin London during summer.  */
 static table const universal_time_zone_table[] =
 {
   { "GMT",      tZONE,     HOUR ( 0) }, /* Greenwich Mean */
@@ -1540,9 +1540,9 @@ mktime_ok (struct tm const *tm0, struct tm const *tm1, 
time_t t)
 {
   if (t == (time_t) -1)
     {
-      /* Guard against falsely reporting an error when parsing a time
-         stamp that happens to equal (time_t) -1, on a host that
-         supports such a time stamp.  */
+      /* Guard against falsely reporting an error when parsing a
+         timestamp that happens to equal (time_t) -1, on a host that
+         supports such a timestamp.  */
       tm1 = localtime (&t);
       if (!tm1)
         return false;
@@ -2034,7 +2034,7 @@ parse_datetime2 (struct timespec *result, char const *p,
             dbg_printf ("warning: using midnight as starting time: 
00:00:00\n");
         }
 
-      /* Let mktime deduce tm_isdst if we have an absolute time stamp.  */
+      /* Let mktime deduce tm_isdst if we have an absolute timestamp.  */
       if (pc.dates_seen | pc.days_seen | pc.times_seen)
         tm.tm_isdst = -1;
 
diff --git a/lib/stat-time.h b/lib/stat-time.h
index b060cc7..9402b3f 100644
--- a/lib/stat-time.h
+++ b/lib/stat-time.h
@@ -181,7 +181,7 @@ get_stat_birthtime (struct stat const *st)
      || defined HAVE_STRUCT_STAT_ST_BIRTHTIMENSEC)
   /* FreeBSD and NetBSD sometimes signal the absence of knowledge by
      using zero.  Attempt to work around this problem.  Alas, this can
-     report failure even for valid time stamps.  Also, NetBSD
+     report failure even for valid timestamps.  Also, NetBSD
      sometimes returns junk in the birth time fields; work around this
      bug if it is detected.  */
   if (! (t.tv_sec && 0 <= t.tv_nsec && t.tv_nsec < 1000000000))
diff --git a/lib/time.in.h b/lib/time.in.h
index 97fa9d2..86436c2 100644
--- a/lib/time.in.h
+++ b/lib/time.in.h
@@ -217,7 +217,7 @@ _GL_CXXALIAS_SYS (gmtime, struct tm *, (time_t const 
*__timer));
 _GL_CXXALIASWARN (gmtime);
 # endif
 
-/* Parse BUF as a time stamp, assuming FORMAT specifies its layout, and store
+/* Parse BUF as a timestamp, assuming FORMAT specifies its layout, and store
    the resulting broken-down time into TM.  See
    <http://www.opengroup.org/susv3xsh/strptime.html>.  */
 # if @GNULIB_STRPTIME@
diff --git a/lib/utimecmp.h b/lib/utimecmp.h
index 4d1d044..11e9d7c 100644
--- a/lib/utimecmp.h
+++ b/lib/utimecmp.h
@@ -1,4 +1,4 @@
-/* utimecmp.h -- compare file time stamps
+/* utimecmp.h -- compare file timestamps
 
    Copyright (C) 2004, 2009-2017 Free Software Foundation, Inc.
 
@@ -26,7 +26,7 @@
 /* Options for utimecmp.  */
 enum
 {
-  /* Before comparing, truncate the source time stamp to the
+  /* Before comparing, truncate the source timestamp to the
      resolution of the destination file system and to the resolution
      of utimens.  */
   UTIMECMP_TRUNCATE_SOURCE = 1
diff --git a/lib/xtime.h b/lib/xtime.h
index 810a3c7..6cea17c 100644
--- a/lib/xtime.h
+++ b/lib/xtime.h
@@ -1,4 +1,4 @@
-/* xtime -- extended-resolution integer time stamps
+/* xtime -- extended-resolution integer timestamps
 
    Copyright (C) 2005-2006, 2009-2017 Free Software Foundation, Inc.
 
@@ -28,7 +28,7 @@ _GL_INLINE_HEADER_BEGIN
 # define XTIME_INLINE _GL_INLINE
 #endif
 
-/* xtime_t is a signed type used for time stamps.  It is an integer
+/* xtime_t is a signed type used for timestamps.  It is an integer
    type that is a count of nanoseconds -- except for obsolescent hosts
    without sufficiently-wide integers, where it is a count of
    seconds.  */
diff --git a/modules/utimecmp b/modules/utimecmp
index 398411e..c7eee89 100644
--- a/modules/utimecmp
+++ b/modules/utimecmp
@@ -1,5 +1,5 @@
 Description:
-compare file time stamps
+compare file timestamps
 
 Files:
 lib/utimecmp.h
diff --git a/tests/test-posixtm.c b/tests/test-posixtm.c
index 499e5cc..069b721 100644
--- a/tests/test-posixtm.c
+++ b/tests/test-posixtm.c
@@ -47,7 +47,7 @@ static struct posixtm_test const T[] =
     { "12131415",        13, 1,            0}, /* ??? Dec 13 14:15:00 ???? */
 
     /* These two tests fail on 64-bit Solaris up through at least
-       Solaris 10, which is off by one day for time stamps before
+       Solaris 10, which is off by one day for timestamps before
        0001-01-01 00:00:00 UTC.  */
     { "000001010000.00", 13, 1,
                       - INT64_C (62167219200)},/* Sat Jan  1 00:00:00 0    */
diff --git a/lib/fdutimensat.c b/lib/fdutimensat.c
index 1475bb0..ff68490 100644
--- a/lib/fdutimensat.c
+++ b/lib/fdutimensat.c
@@ -27,14 +27,14 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 
 /* Set the access and modification time stamps of FD (a.k.a. FILE) to be
    TIMESPEC[0] and TIMESPEC[1], respectively; relative to directory DIR.
    FD must be either negative -- in which case it is ignored --
    or a file descriptor that is open on FILE.
    If FD is nonnegative, then FILE can be NULL, which means
    use just futimes (or equivalent) instead of utimes (or equivalent),
    and fail if on an old system without futimes (or equivalent).
-   If TIMESPEC is null, set the time stamps to the current time.
+   If TIMESPEC is null, set the timestamps to the current time.
    ATFLAG is passed to utimensat if FD is negative or futimens was
    unsupported, which can allow operation on FILE as a symlink.
    Return 0 on success, -1 (setting errno) on failure.  */
@@ -27,14 +27,14 @@
 #include <sys/stat.h>
 
-/* Set the access and modification time stamps of FD (a.k.a. FILE) to be
+/* Set the access and modification timestamps of FD (a.k.a. FILE) to be
    TIMESPEC[0] and TIMESPEC[1], respectively; relative to directory DIR.
    FD must be either negative -- in which case it is ignored --
diff --git a/lib/futimens.c b/lib/futimens.c
index d370568..213e9b7 100644
--- a/lib/futimens.c
+++ b/lib/futimens.c
@@ -22,10 +22,10 @@
 
 #include "utimens.h"
 
 /* Set the access and modification time stamps of FD to be
    TIMESPEC[0] and TIMESPEC[1], respectively.
    Fail with ENOSYS on systems without futimes (or equivalent).
-   If TIMESPEC is null, set the time stamps to the current time.
+   If TIMESPEC is null, set the timestamps to the current time.
    Return 0 on success, -1 (setting errno) on failure.  */
 int
 futimens (int fd, struct timespec const times[2])
@@ -22,10 +22,10 @@
 #include "utimens.h"
 
-/* Set the access and modification time stamps of FD to be
+/* Set the access and modification timestamps of FD to be
    TIMESPEC[0] and TIMESPEC[1], respectively.
    Fail with ENOSYS on systems without futimes (or equivalent).
diff --git a/lib/timespec.h b/lib/timespec.h
index fc7b3d1..a5eca79 100644
--- a/lib/timespec.h
+++ b/lib/timespec.h
@@ -29,7 +29,7 @@ _GL_INLINE_HEADER_BEGIN
 # define _GL_TIMESPEC_INLINE _GL_INLINE
 #endif
 
 /* Resolution of timespec time stamps (in units per second), and log
    base 10 of the resolution.  */
 
 enum { TIMESPEC_RESOLUTION = 1000000000 };
@@ -48,7 +48,7 @@ make_timespec (time_t s, long int ns)
 
 /* Return negative, zero, positive if A < B, A == B, A > B, respectively.
 
-   For each time stamp T, this code assumes that either:
+   For each timestamp T, this code assumes that either:
 
      * T.tv_nsec is in the range 0..999999999; or
      * T.tv_sec corresponds to a valid leap second on a host that supports
@@ -56,7 +56,7 @@ make_timespec (time_t s, long int ns)
      * T.tv_sec is the minimum time_t value and T.tv_nsec is -1; or
        T.tv_sec is the maximum time_t value and T.tv_nsec is 2000000000.
        This allows for special struct timespec values that are less or
-       greater than all possible valid time stamps.
+       greater than all possible valid timestamps.
 
    In all these cases, it is safe to subtract two tv_nsec values and
    convert the result to integer without worrying about overflow on
@@ -29,7 +29,7 @@ _GL_INLINE_HEADER_BEGIN
 #endif
 
-/* Resolution of timespec time stamps (in units per second), and log
+/* Resolution of timespec timestamps (in units per second), and log
    base 10 of the resolution.  */
 
diff --git a/lib/utimecmp.c b/lib/utimecmp.c
index 1d7745f..cd773ae 100644
--- a/lib/utimecmp.c
+++ b/lib/utimecmp.c
@@ -1,4 +1,4 @@
 /* utimecmp.c -- compare file time stamps
 
    Copyright (C) 2004-2007, 2009-2017 Free Software Foundation, Inc.
 
@@ -56,13 +56,13 @@ enum { SYSCALL_RESOLUTION = 1000 };
 enum { SYSCALL_RESOLUTION = BILLION };
 #endif
 
 /* Describe a file system and its time stamp resolution in nanoseconds.  */
 struct fs_res
 {
   /* Device number of file system.  */
   dev_t dev;
 
   /* An upper bound on the time stamp resolution of this file system,
      ignoring any resolution that cannot be set via utimens.  It is
      represented by an integer count of nanoseconds.  It must be
      either 2 billion, or a power of 10 that is no greater than a
@@ -108,9 +108,9 @@ dev_info_compare (void const *x, void const *y)
    If OPTIONS & UTIMECMP_TRUNCATE_SOURCE, do the comparison after SRC is
    converted to the destination's timestamp resolution as filtered through
    utimens.  In this case, return -2 if the exact answer cannot be
-   determined; this can happen only if the time stamps are very close and
+   determined; this can happen only if the timestamps are very close and
    there is some trouble accessing the file system (e.g., the user does not
-   have permission to futz with the destination's time stamps).  */
+   have permission to futz with the destination's timestamps).  */
 
 int
 utimecmp (char const *dst_name,
@@ -133,7 +133,7 @@ utimecmp (char const *dst_name,
 
   verify (TYPE_IS_INTEGER (time_t));
 
   /* Destination and source time stamps.  */
   time_t dst_s = dst_stat->st_mtime;
   time_t src_s = src_stat->st_mtime;
   int dst_ns = get_stat_mtime_ns (dst_stat);
@@ -141,7 +141,7 @@ utimecmp (char const *dst_name,
 
   if (options & UTIMECMP_TRUNCATE_SOURCE)
     {
       /* Look up the time stamp resolution for the destination device.  */
 
       /* Hash table for caching information learned about devices.  */
       static Hash_table *ht;
@@ -151,7 +151,7 @@ utimecmp (char const *dst_name,
       struct fs_res *dst_res = NULL;
       struct fs_res tmp_dst_res;
 
       /* Time stamp resolution in nanoseconds.  */
       int res;
 
       /* Quick exit, if possible.  Since the worst resolution is 2
@@ -280,13 +280,13 @@ utimecmp (char const *dst_name,
               struct timespec timespec[2];
               struct stat dst_status;
 
               /* Ignore source time stamp information that must necessarily
                  be lost when filtered through utimens.  */
               src_ns -= src_ns % SYSCALL_RESOLUTION;
 
-              /* If the time stamps disagree widely enough, there's no need
-                 to interrogate the file system to deduce the exact time
-                 stamp resolution; return the answer directly.  */
+              /* If the timestamps disagree widely enough, there's no need
+                 to interrogate the file system to deduce the exact
+                 timestamp resolution; return the answer directly.  */
               {
                 time_t s = src_s & ~ (res == 2 * BILLION ? 1 : 0);
                 if (src_s < dst_s || (src_s == dst_s && src_ns <= dst_ns))
@@ -296,9 +296,9 @@ utimecmp (char const *dst_name,
                   return -1;
               }
 
               /* Determine the actual time stamp resolution for the
                  destination file system (after truncation due to
-                 SYSCALL_RESOLUTION) by setting the access time stamp of the
+                 SYSCALL_RESOLUTION) by setting the access timestamp of the
                  destination to the existing access time, except with
                  trailing nonzero digits.  */
 
@@ -366,12 +366,12 @@ utimecmp (char const *dst_name,
           dst_res->exact = true;
         }
 
       /* Truncate the source's time stamp according to the resolution.  */
       src_s &= ~ (res == 2 * BILLION ? 1 : 0);
       src_ns -= src_ns % res;
     }
 
   /* Compare the time stamps and return -1, 0, 1 accordingly.  */
   return (dst_s < src_s ? -1
           : dst_s > src_s ? 1
           : dst_ns < src_ns ? -1
@@ -1,4 +1,4 @@
-/* utimecmp.c -- compare file time stamps
+/* utimecmp.c -- compare file timestamps
 
    Copyright (C) 2004-2007, 2009-2017 Free Software Foundation, Inc.
@@ -56,13 +56,13 @@ enum { SYSCALL_RESOLUTION = 1000 };
 #endif
 
-/* Describe a file system and its time stamp resolution in nanoseconds.  */
+/* Describe a file system and its timestamp resolution in nanoseconds.  */
 struct fs_res
 {
@@ -56,13 +56,13 @@ enum { SYSCALL_RESOLUTION = 1000 };
   dev_t dev;
 
-  /* An upper bound on the time stamp resolution of this file system,
+  /* An upper bound on the timestamp resolution of this file system,
      ignoring any resolution that cannot be set via utimens.  It is
      represented by an integer count of nanoseconds.  It must be
@@ -133,7 +133,7 @@ utimecmp (char const *dst_name,
   verify (TYPE_IS_INTEGER (time_t));
 
-  /* Destination and source time stamps.  */
+  /* Destination and source timestamps.  */
   time_t dst_s = dst_stat->st_mtime;
   time_t src_s = src_stat->st_mtime;
@@ -141,7 +141,7 @@ utimecmp (char const *dst_name,
   if (options & UTIMECMP_TRUNCATE_SOURCE)
     {
-      /* Look up the time stamp resolution for the destination device.  */
+      /* Look up the timestamp resolution for the destination device.  */
 
       /* Hash table for caching information learned about devices.  */
@@ -151,7 +151,7 @@ utimecmp (char const *dst_name,
       struct fs_res tmp_dst_res;
 
-      /* Time stamp resolution in nanoseconds.  */
+      /* timestamp resolution in nanoseconds.  */
       int res;
 
@@ -280,13 +280,13 @@ utimecmp (char const *dst_name,
               struct stat dst_status;
 
-              /* Ignore source time stamp information that must necessarily
+              /* Ignore source timestamp information that must necessarily
                  be lost when filtered through utimens.  */
               src_ns -= src_ns % SYSCALL_RESOLUTION;
@@ -296,9 +296,9 @@ utimecmp (char const *dst_name,
               }
 
-              /* Determine the actual time stamp resolution for the
+              /* Determine the actual timestamp resolution for the
                  destination file system (after truncation due to
@@ -366,12 +366,12 @@ utimecmp (char const *dst_name,
         }
 
-      /* Truncate the source's time stamp according to the resolution.  */
+      /* Truncate the source's timestamp according to the resolution.  */
       src_s &= ~ (res == 2 * BILLION ? 1 : 0);
       src_ns -= src_ns % res;
@@ -366,12 +366,12 @@ utimecmp (char const *dst_name,
     }
 
-  /* Compare the time stamps and return -1, 0, 1 accordingly.  */
+  /* Compare the timestamps and return -1, 0, 1 accordingly.  */
   return (dst_s < src_s ? -1
           : dst_s > src_s ? 1
diff --git a/lib/utimens.c b/lib/utimens.c
index e2bb702..3643668 100644
--- a/lib/utimens.c
+++ b/lib/utimens.c
@@ -154,14 +154,14 @@ update_timespec (struct stat const *statbuf, struct 
timespec *ts[2])
   return false;
 }
 
 /* Set the access and modification time stamps of FD (a.k.a. FILE) to be
    TIMESPEC[0] and TIMESPEC[1], respectively.
    FD must be either negative -- in which case it is ignored --
    or a file descriptor that is open on FILE.
    If FD is nonnegative, then FILE can be NULL, which means
    use just futimes (or equivalent) instead of utimes (or equivalent),
    and fail if on an old system without futimes (or equivalent).
-   If TIMESPEC is null, set the time stamps to the current time.
+   If TIMESPEC is null, set the timestamps to the current time.
    Return 0 on success, -1 (setting errno) on failure.  */
 
 int
@@ -190,7 +190,7 @@ fdutimens (int fd, char const *file, struct timespec const 
timespec[2])
       return -1;
     }
 
   /* Some Linux-based NFS clients are buggy, and mishandle time stamps
      of files in NFS file systems in some cases.  We have no
      configure-time test for this, but please see
      <http://bugs.gentoo.org/show_bug.cgi?id=132673> for references to
@@ -411,7 +411,7 @@ fdutimens (int fd, char const *file, struct timespec const 
timespec[2])
   }
 }
 
 /* Set the access and modification time stamps of FILE to be
    TIMESPEC[0] and TIMESPEC[1], respectively.  */
 int
 utimens (char const *file, struct timespec const timespec[2])
@@ -419,7 +419,7 @@ utimens (char const *file, struct timespec const 
timespec[2])
   return fdutimens (-1, file, timespec);
 }
 
 /* Set the access and modification time stamps of FILE to be
    TIMESPEC[0] and TIMESPEC[1], respectively, without dereferencing
    symlinks.  Fail with ENOSYS if the platform does not support
    changing symlink timestamps, but FILE was a symlink.  */
@@ -154,14 +154,14 @@ update_timespec (struct stat const *statbuf, struct 
 }
 
-/* Set the access and modification time stamps of FD (a.k.a. FILE) to be
+/* Set the access and modification timestamps of FD (a.k.a. FILE) to be
    TIMESPEC[0] and TIMESPEC[1], respectively.
    FD must be either negative -- in which case it is ignored --
@@ -190,7 +190,7 @@ fdutimens (int fd, char const *file, struct timespec const 
     }
 
-  /* Some Linux-based NFS clients are buggy, and mishandle time stamps
+  /* Some Linux-based NFS clients are buggy, and mishandle timestamps
      of files in NFS file systems in some cases.  We have no
      configure-time test for this, but please see
@@ -411,7 +411,7 @@ fdutimens (int fd, char const *file, struct timespec const 
 }
 
-/* Set the access and modification time stamps of FILE to be
+/* Set the access and modification timestamps of FILE to be
    TIMESPEC[0] and TIMESPEC[1], respectively.  */
 int
@@ -419,7 +419,7 @@ utimens (char const *file, struct timespec const 
 }
 
-/* Set the access and modification time stamps of FILE to be
+/* Set the access and modification timestamps of FILE to be
    TIMESPEC[0] and TIMESPEC[1], respectively, without dereferencing
    symlinks.  Fail with ENOSYS if the platform does not support
diff --git a/lib/utimensat.c b/lib/utimensat.c
index 7c5ee89..7605747 100644
--- a/lib/utimensat.c
+++ b/lib/utimensat.c
@@ -133,11 +133,11 @@ rpl_utimensat (int fd, char const *file, struct timespec 
const times[2],
 
 #endif /* !HAVE_UTIMENSAT */
 
 /* Set the access and modification time stamps of FILE to be
    TIMESPEC[0] and TIMESPEC[1], respectively; relative to directory
    FD.  If flag is AT_SYMLINK_NOFOLLOW, change the times of a symlink,
    or fail with ENOSYS if not possible.  If TIMESPEC is null, set the
-   time stamps to the current time.  If possible, do it without
+   timestamps to the current time.  If possible, do it without
    changing the working directory.  Otherwise, resort to using
    save_cwd/fchdir, then utimens/restore_cwd.  If either the save_cwd
    or the restore_cwd fails, then give a diagnostic and exit nonzero.
@@ -133,11 +133,11 @@ rpl_utimensat (int fd, char const *file, struct timespec 
 #endif /* !HAVE_UTIMENSAT */
 
-/* Set the access and modification time stamps of FILE to be
+/* Set the access and modification timestamps of FILE to be
    TIMESPEC[0] and TIMESPEC[1], respectively; relative to directory
    FD.  If flag is AT_SYMLINK_NOFOLLOW, change the times of a symlink,
-- 
2.9.3




reply via email to

[Prev in Thread] Current Thread [Next in Thread]